@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -49,6 +49,33 @@ class AsrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAsrKeyWordLib(self, request):
+        """用户通过本接口进行关键字词表的创建。
+        <br>•   默认每个用户最多可创建30个关键字词表。
+        <br>•   每个关键词词表最多可添加100个词，每个词最多5个汉字或15个字符。
+        <br>•   词表通过本地文件形式上传。
+        <br>•   本地文件必须为UTF-8编码格式，每行仅添加一个词且不能包含标点和特殊字符。
+
+        :param request: Request instance for CreateAsrKeyWordLib.
+        :type request: :class:`tencentcloud.asr.v20190614.models.CreateAsrKeyWordLibRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.CreateAsrKeyWordLibResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAsrKeyWordLib", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAsrKeyWordLibResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateAsrVocab(self, request):
         """用户通过本接口进行热词表的创建。
         <br>•   默认最多可创建30个热词表。
@@ -137,7 +164,7 @@ class AsrClient(AbstractClient):
         • 返回时效：异步回调，非实时返回。最长3小时返回识别结果，**大多数情况下，1小时的音频1-3分钟即可完成识别**。请注意：上述返回时长不含音频下载时延，且30分钟内发送超过1000小时录音或2万条任务的情况除外
         • 音频格式：wav、mp3、m4a、flv、mp4、wma、3gp、amr、aac、ogg-opus、flac
         • 支持语言：在本页面上搜索 **EngineModelType**，或前往 [产品功能](https://cloud.tencent.com/document/product/1093/35682) 查看
-        • 音频提交方式：本接口支持**音频 URL 、本地音频文件**两种请求方式。推荐使用 [腾讯云COS](https://cloud.tencent.com/document/product/436/38484) 来存储、生成URL并提交任务，此种方式将不产生外网和流量下行费用，可节约成本、提升任务速度（COS桶权限需要设置公有读私有写，或URL设置外部可访问）
+        • 音频提交方式：本接口支持**音频 URL 、本地音频文件**两种请求方式。推荐使用 [腾讯云COS](https://cloud.tencent.com/document/product/436/38484) 来存储、生成URL并提交任务，此种方式将不产生外网和流量下行费用，可节约成本、提升任务速度（可参考COS预签名指南：[使用预签名 URL 访问 COS](https://cloud.tencent.com/document/product/436/68284) ，获取COS预签名url）
         • 音频限制：音频 URL 时长不能大于5小时，文件大小不超过1GB；本地音频文件不能大于5MB
         • 如何获取识别结果：支持**回调或轮询**的方式获取结果，具体请参考 [录音文件识别结果查询](https://cloud.tencent.com/document/product/1093/37822)
         • 识别结果有效时间：识别结果在服务端保存24小时
@@ -163,6 +190,29 @@ class AsrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteAsrKeyWordLib(self, request):
+        """用户通过本接口进行关键词表的删除。
+
+        :param request: Request instance for DeleteAsrKeyWordLib.
+        :type request: :class:`tencentcloud.asr.v20190614.models.DeleteAsrKeyWordLibRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.DeleteAsrKeyWordLibResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAsrKeyWordLib", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAsrKeyWordLibResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteAsrVocab(self, request):
         """用户通过本接口进行热词表的删除。
 
@@ -308,6 +358,29 @@ class AsrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def GetAsrKeyWordLibList(self, request):
+        """用户通过该接口，可获得所有的关键词表及其信息。
+
+        :param request: Request instance for GetAsrKeyWordLibList.
+        :type request: :class:`tencentcloud.asr.v20190614.models.GetAsrKeyWordLibListRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.GetAsrKeyWordLibListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetAsrKeyWordLibList", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetAsrKeyWordLibListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def GetAsrVocab(self, request):
         """用户根据词表的ID可以获取对应的热词表信息
 
@@ -400,6 +473,29 @@ class AsrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def GetUsageByDate(self, request):
+        """查询用户用量
+
+        :param request: Request instance for GetUsageByDate.
+        :type request: :class:`tencentcloud.asr.v20190614.models.GetUsageByDateRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.GetUsageByDateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetUsageByDate", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetUsageByDateResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyCustomization(self, request):
         """用户通过该接口可以更新自学习模型，如模型名称、模型类型、模型语料。
 
@@ -447,7 +543,13 @@ class AsrClient(AbstractClient):
 
 
     def SentenceRecognition(self, request):
-        """本接口用于对60秒之内的短音频文件进行识别。<br>•   支持中文普通话、英语、粤语、日语、越南语、马来语、印度尼西亚语、菲律宾语、泰语、葡萄牙语、土耳其语、阿拉伯语、印地语、法语、德语、上海话、四川话、武汉话、贵阳话、昆明话、西安话、郑州话、太原话、兰州话、银川话、西宁话、南京话、合肥话、南昌话、长沙话、苏州话、杭州话、济南话、天津话、石家庄话、黑龙江话、吉林话、辽宁话。<br>•   支持本地语音文件上传和语音URL上传两种请求方式，音频时长不能超过60s，音频文件大小不能超过3MB。<br>•   音频格式支持wav、pcm、ogg-opus、speex、silk、mp3、m4a、aac、 amr。<br>•   请求方法为 HTTP POST , Content-Type为"application/json; charset=utf-8"<br>•   签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。<br>•   默认接口请求频率限制：30次/秒，如您有提高请求频率限制的需求，请[前往购买](https://buy.cloud.tencent.com/asr)。
+        """本接口用于对60秒之内的短音频文件进行识别。
+        •   支持中文普通话、英语、粤语、日语、越南语、马来语、印度尼西亚语、菲律宾语、泰语、葡萄牙语、土耳其语、阿拉伯语、印地语、法语、德语、上海话、四川话、武汉话、贵阳话、昆明话、西安话、郑州话、太原话、兰州话、银川话、西宁话、南京话、合肥话、南昌话、长沙话、苏州话、杭州话、济南话、天津话、石家庄话、黑龙江话、吉林话、辽宁话。
+        •   支持本地语音文件上传和语音URL上传两种请求方式，音频时长不能超过60s，音频文件大小不能超过3MB。推荐使用 [腾讯云COS](https://cloud.tencent.com/document/product/436/38484) 来存储音频、生成URL并提交请求，此种方式会走内网下载音频，极大降低整体请求时延；并且不会产生外网和流量下行费用，可节约成本（可参考COS预签名指南：[使用预签名 URL 访问 COS](https://cloud.tencent.com/document/product/436/68284) ，获取COS预签名url）
+        •   音频格式支持wav、pcm、ogg-opus、speex、silk、mp3、m4a、aac、 amr。
+        •   请求方法为 HTTP POST , Content-Type为"application/json; charset=utf-8"
+        •   签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。
+        •   默认接口请求频率限制：30次/秒，如您有提高请求频率限制的需求，请[前往购买](https://buy.cloud.tencent.com/asr)。
 
         :param request: Request instance for SentenceRecognition.
         :type request: :class:`tencentcloud.asr.v20190614.models.SentenceRecognitionRequest`
@@ -492,6 +594,29 @@ class AsrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def UpdateAsrKeyWordLib(self, request):
+        """用户通过本接口进行对应的关键词表信息更新。
+
+        :param request: Request instance for UpdateAsrKeyWordLib.
+        :type request: :class:`tencentcloud.asr.v20190614.models.UpdateAsrKeyWordLibRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.UpdateAsrKeyWordLibResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateAsrKeyWordLib", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateAsrKeyWordLibResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def UpdateAsrVocab(self, request):
         """用户通过本接口进行对应的词表信息更新。
 
@@ -613,6 +738,29 @@ class AsrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def VoicePrintGroupVerify(self, request):
+        """说话人验证1:N接口，可以通过传入一段说话人音频，并且指定已存在的groupId, 和返回topN,  接口返回groupId内所有声纹和传入音频声纹比对打分TopN的结果。
+
+        :param request: Request instance for VoicePrintGroupVerify.
+        :type request: :class:`tencentcloud.asr.v20190614.models.VoicePrintGroupVerifyRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.VoicePrintGroupVerifyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("VoicePrintGroupVerify", params, headers=headers)
+            response = json.loads(body)
+            model = models.VoicePrintGroupVerifyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def VoicePrintUpdate(self, request):
         """本接口用于更新和覆盖已注册的音频数据和说话人昵称，更新后原有的音频数据将失效。
 
