@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,6 +17,9 @@
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
+# 参数错误。
+INVALIDPARAMETER = 'InvalidParameter'
+
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
