@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -72,22 +72,20 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def ConvertDocument(self, request):
-        """产品规划
+    def CreateAgent(self, request):
+        """你创建一个Agent
 
-        接口支持图片和PDF转可编辑word格式文件，将文件中的图片、文本、表格等元素识别，并根据位置进行还原。
-
-        :param request: Request instance for ConvertDocument.
-        :type request: :class:`tencentcloud.lke.v20231130.models.ConvertDocumentRequest`
-        :rtype: :class:`tencentcloud.lke.v20231130.models.ConvertDocumentResponse`
+        :param request: Request instance for CreateAgent.
+        :type request: :class:`tencentcloud.lke.v20231130.models.CreateAgentRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.CreateAgentResponse`
 
         """
         try:
             params = request._serialize()
             headers = request.headers
-            body = self.call("ConvertDocument", params, headers=headers)
+            body = self.call("CreateAgent", params, headers=headers)
             response = json.loads(body)
-            model = models.ConvertDocumentResponse()
+            model = models.CreateAgentResponse()
             model._deserialize(response["Response"])
             return model
         except Exception as e:
@@ -143,29 +141,6 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def CreateCorp(self, request):
-        """创建企业
-
-        :param request: Request instance for CreateCorp.
-        :type request: :class:`tencentcloud.lke.v20231130.models.CreateCorpRequest`
-        :rtype: :class:`tencentcloud.lke.v20231130.models.CreateCorpResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("CreateCorp", params, headers=headers)
-            response = json.loads(body)
-            model = models.CreateCorpResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def CreateDocCate(self, request):
         """创建Doc分类
 
@@ -235,32 +210,6 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def CreateReconstructDocumentFlow(self, request):
-        """本接口为异步接口的发起请求接口，用于发起文档解析任务。
-        文档解析支持将图片或PDF文件转换成Markdown格式文件，可解析包括表格、公式、图片、标题、段落、页眉、页脚等内容元素，并将内容智能转换成阅读顺序。
-
-        体验期间单账号限制qps仅为1，若有正式接入需要请与产研团队沟通开放。
-
-        :param request: Request instance for CreateReconstructDocumentFlow.
-        :type request: :class:`tencentcloud.lke.v20231130.models.CreateReconstructDocumentFlowRequest`
-        :rtype: :class:`tencentcloud.lke.v20231130.models.CreateReconstructDocumentFlowResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("CreateReconstructDocumentFlow", params, headers=headers)
-            response = json.loads(body)
-            model = models.CreateReconstructDocumentFlowResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def CreateRejectedQuestion(self, request):
         """创建拒答问题
 
@@ -307,6 +256,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateSharedKnowledge(self, request):
+        """创建共享知识库。
+
+        :param request: Request instance for CreateSharedKnowledge.
+        :type request: :class:`tencentcloud.lke.v20231130.models.CreateSharedKnowledgeRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.CreateSharedKnowledgeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateSharedKnowledge", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateSharedKnowledgeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateVar(self, request):
         """创建变量
 
@@ -330,6 +302,53 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateWorkflowRun(self, request):
+        """本接口用来创建工作流的异步运行实例，创建成功后工作流会在后台异步运行，接口返回工作流运行实例ID（WorkflowRunId）等信息。后面可通过调用DescribeWorkflowRun接口查工作流运行的详情。
+        注意：工作流的异步运行是基于应用的，需要先把对应的应用配置成“单工作流模式”，并且打开“异步调用”的开关，才能创建成功。
+
+        :param request: Request instance for CreateWorkflowRun.
+        :type request: :class:`tencentcloud.lke.v20231130.models.CreateWorkflowRunRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.CreateWorkflowRunResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateWorkflowRun", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateWorkflowRunResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteAgent(self, request):
+        """删除Agent
+
+        :param request: Request instance for DeleteAgent.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DeleteAgentRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DeleteAgentResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAgent", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAgentResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteApp(self, request):
         """删除应用
 
@@ -491,6 +510,52 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteSharedKnowledge(self, request):
+        """删除共享知识库。
+
+        :param request: Request instance for DeleteSharedKnowledge.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DeleteSharedKnowledgeRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DeleteSharedKnowledgeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteSharedKnowledge", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteSharedKnowledgeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteVar(self, request):
+        """删除变量
+
+        :param request: Request instance for DeleteVar.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DeleteVarRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DeleteVarResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteVar", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteVarResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeApp(self, request):
         """获取企业下应用详情
 
@@ -514,6 +579,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAppAgentList(self, request):
+        """查询指定应用下的Agent列表
+
+        :param request: Request instance for DescribeAppAgentList.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DescribeAppAgentListRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DescribeAppAgentListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAppAgentList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAppAgentListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAttributeLabel(self, request):
         """查询属性标签详情
 
@@ -606,29 +694,6 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def DescribeCorp(self, request):
-        """企业详情
-
-        :param request: Request instance for DescribeCorp.
-        :type request: :class:`tencentcloud.lke.v20231130.models.DescribeCorpRequest`
-        :rtype: :class:`tencentcloud.lke.v20231130.models.DescribeCorpResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeCorp", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeCorpResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def DescribeDoc(self, request):
         """文档详情
 
@@ -698,6 +763,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeNodeRun(self, request):
+        """通过DescribeWorkflowRun接口获取了工作流异步运行的整体内容，其中包含了基本的节点信息，再通用本接口可查看节点的运行详情（包括输入、输出、日志等）。
+
+        :param request: Request instance for DescribeNodeRun.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DescribeNodeRunRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DescribeNodeRunResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeNodeRun", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeNodeRunResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeQA(self, request):
         """问答详情
 
@@ -859,6 +947,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeSharedKnowledge(self, request):
+        """查询共享知识库。
+
+        :param request: Request instance for DescribeSharedKnowledge.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DescribeSharedKnowledgeRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DescribeSharedKnowledgeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSharedKnowledge", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSharedKnowledgeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeStorageCredential(self, request):
         """获取文件上传临时密钥
 
@@ -951,6 +1062,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeWorkflowRun(self, request):
+        """创建了工作流的异步运行实例后，通过本接口可以查询整体的运行详情。
+
+        :param request: Request instance for DescribeWorkflowRun.
+        :type request: :class:`tencentcloud.lke.v20231130.models.DescribeWorkflowRunRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.DescribeWorkflowRunResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeWorkflowRun", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeWorkflowRunResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ExportAttributeLabel(self, request):
         """导出属性标签
 
@@ -1135,31 +1269,6 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def GetEmbedding(self, request):
-        """本接口（GetEmbedding）调用文本表示模型，将文本转化为用数值表示的向量形式，可用于文本检索、信息推荐、知识挖掘等场景。
-        开通[产品体验](https://lke.cloud.tencent.com/lke/#/trialProduct)后可获得50wtoken体验额度。
-        本接口（GetEmbedding）有单账号调用上限控制，如您有提高并发限制的需求请 [联系我们](https://cloud.tencent.com/act/event/Online_service) 。
-
-        :param request: Request instance for GetEmbedding.
-        :type request: :class:`tencentcloud.lke.v20231130.models.GetEmbeddingRequest`
-        :rtype: :class:`tencentcloud.lke.v20231130.models.GetEmbeddingResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("GetEmbedding", params, headers=headers)
-            response = json.loads(body)
-            model = models.GetEmbeddingResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def GetLikeDataCount(self, request):
         """点赞点踩数据统计
 
@@ -1207,29 +1316,6 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def GetReconstructDocumentResult(self, request):
-        """本接口为异步接口的查询结果接口，用于获取文档解析处理结果。
-
-        :param request: Request instance for GetReconstructDocumentResult.
-        :type request: :class:`tencentcloud.lke.v20231130.models.GetReconstructDocumentResultRequest`
-        :rtype: :class:`tencentcloud.lke.v20231130.models.GetReconstructDocumentResultResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("GetReconstructDocumentResult", params, headers=headers)
-            response = json.loads(body)
-            model = models.GetReconstructDocumentResultResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def GetTaskStatus(self, request):
         """获取任务状态
 
@@ -1598,6 +1684,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ListReferShareKnowledge(self, request):
+        """查看应用引用了哪些共享知识库，可以看到共享知识库的基础信息，包括名称，id等
+
+        :param request: Request instance for ListReferShareKnowledge.
+        :type request: :class:`tencentcloud.lke.v20231130.models.ListReferShareKnowledgeRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.ListReferShareKnowledgeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListReferShareKnowledge", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListReferShareKnowledgeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ListRejectedQuestion(self, request):
         """获取拒答问题
 
@@ -1759,6 +1868,29 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ListSharedKnowledge(self, request):
+        """列举共享知识库。
+
+        :param request: Request instance for ListSharedKnowledge.
+        :type request: :class:`tencentcloud.lke.v20231130.models.ListSharedKnowledgeRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.ListSharedKnowledgeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListSharedKnowledge", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListSharedKnowledgeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ListUnsatisfiedReply(self, request):
         """查询不满意回复列表
 
@@ -1805,6 +1937,52 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ListWorkflowRuns(self, request):
+        """此接口可查询已创建的所有工作流异步运行实例。
+
+        :param request: Request instance for ListWorkflowRuns.
+        :type request: :class:`tencentcloud.lke.v20231130.models.ListWorkflowRunsRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.ListWorkflowRunsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListWorkflowRuns", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListWorkflowRunsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyAgent(self, request):
+        """修改Agent信息
+
+        :param request: Request instance for ModifyAgent.
+        :type request: :class:`tencentcloud.lke.v20231130.models.ModifyAgentRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.ModifyAgentResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyAgent", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyAgentResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyApp(self, request):
         """修改应用请求结构体
 
@@ -2012,30 +2190,6 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def QueryRewrite(self, request):
-        """多轮改写（QueryRewrite）主要用于多轮对话中，进行指代消解和省略补全。使用本接口，无需输入prompt描述，根据对话历史即可生成更精确的用户查询。在应用场景上，本接口可应用于智能问答、对话式搜索等多种场景。
-        开通[产品体验](https://lke.cloud.tencent.com/lke/#/trialProduct)后可获得50wtoken体验额度。本接口（QueryRewrite）有单账号调用上限控制，如您有提高并发限制的需求请 [联系我们](https://cloud.tencent.com/act/event/Online_service) 。
-
-        :param request: Request instance for QueryRewrite.
-        :type request: :class:`tencentcloud.lke.v20231130.models.QueryRewriteRequest`
-        :rtype: :class:`tencentcloud.lke.v20231130.models.QueryRewriteResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("QueryRewrite", params, headers=headers)
-            response = json.loads(body)
-            model = models.QueryRewriteResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def RateMsgRecord(self, request):
         """点赞点踩消息
 
@@ -2059,22 +2213,20 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def ReconstructDocument(self, request):
-        """支持将图片或PDF文件转换成Markdown格式文件，可解析包括表格、公式、图片、标题、段落、页眉、页脚等内容元素，并将内容智能转换成阅读顺序。
+    def ReferShareKnowledge(self, request):
+        """应用引用共享知识库，可以引用一个或多个，每次都是全量覆盖
 
-        体验期间单账号限制qps仅为1，若有正式接入需要请与产研团队沟通开放。
-
-        :param request: Request instance for ReconstructDocument.
-        :type request: :class:`tencentcloud.lke.v20231130.models.ReconstructDocumentRequest`
-        :rtype: :class:`tencentcloud.lke.v20231130.models.ReconstructDocumentResponse`
+        :param request: Request instance for ReferShareKnowledge.
+        :type request: :class:`tencentcloud.lke.v20231130.models.ReferShareKnowledgeRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.ReferShareKnowledgeResponse`
 
         """
         try:
             params = request._serialize()
             headers = request.headers
-            body = self.call("ReconstructDocument", params, headers=headers)
+            body = self.call("ReferShareKnowledge", params, headers=headers)
             response = json.loads(body)
-            model = models.ReconstructDocumentResponse()
+            model = models.ReferShareKnowledgeResponse()
             model._deserialize(response["Response"])
             return model
         except Exception as e:
@@ -2176,29 +2328,6 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def RunReRank(self, request):
-        """基于知识引擎精调模型技术的rerank模型，支持对多路召回的结果进行重排序，根据query与切片内容的相关性，按分数由高到低对切片进行排序，并输出对应的打分结果。（这个接口已下线，请使用新接口，接口文档：https://cloud.tencent.com/document/product/1772/115339）。
-
-        :param request: Request instance for RunReRank.
-        :type request: :class:`tencentcloud.lke.v20231130.models.RunReRankRequest`
-        :rtype: :class:`tencentcloud.lke.v20231130.models.RunReRankResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("RunReRank", params, headers=headers)
-            response = json.loads(body)
-            model = models.RunReRankResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def SaveDoc(self, request):
         """知识库文档问答保存。
         将文件存储到应用的知识库内需要三步：
@@ -2250,6 +2379,75 @@ class LkeClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def StopWorkflowRun(self, request):
+        """此接口用来停止正在进行的工作流异步运行实例。
+
+        :param request: Request instance for StopWorkflowRun.
+        :type request: :class:`tencentcloud.lke.v20231130.models.StopWorkflowRunRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.StopWorkflowRunResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StopWorkflowRun", params, headers=headers)
+            response = json.loads(body)
+            model = models.StopWorkflowRunResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def UpdateSharedKnowledge(self, request):
+        """更新共享知识库。
+
+        :param request: Request instance for UpdateSharedKnowledge.
+        :type request: :class:`tencentcloud.lke.v20231130.models.UpdateSharedKnowledgeRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.UpdateSharedKnowledgeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateSharedKnowledge", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateSharedKnowledgeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def UpdateVar(self, request):
+        """更新变量
+
+        :param request: Request instance for UpdateVar.
+        :type request: :class:`tencentcloud.lke.v20231130.models.UpdateVarRequest`
+        :rtype: :class:`tencentcloud.lke.v20231130.models.UpdateVarResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateVar", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateVarResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def UploadAttributeLabel(self, request):
         """上传导入属性标签
 
