@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,9 +14,18 @@
 # limitations under the License.
 
 
+# CAM签名/鉴权错误。
+AUTHFAILURE = 'AuthFailure'
+
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 文档正在解析中不允许删除
+FAILEDOPERATION_DOCPARSINGNOTDELETE = 'FailedOperation.DocParsingNotDelete'
+
+# 低码用户不存在。
+FAILEDOPERATION_LOWCODEUSERNOTEXIST = 'FailedOperation.LowcodeUserNotExist'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
